from setuptools import setup, find_packages

setup(
    name="jarvisfileopen",
    version="1.0.0",
    description="Libreria per aprire file in stile Jarvis con un semplice comando: open",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Mattia Leoni",
    author_email="mattia.leoni15@icloud.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires=">=3.6"
)
